@@ -1,5 +1,4 @@
 pkg_env <- new.env(parent = emptyenv())
-pkg_env$children <- NULL
 pkg_env$version <- NULL
 pkg_env$exported_date <- NULL
 pkg_env$root <- NULL
@@ -10,9 +9,9 @@ get_dataset_full_path <- function(data, csv_path = ".") {
   ))
 }
 
-write_csv <- function(data, save_csv = FALSE, csv_path = ".") {
+write_csv <- function(data, save_csv = FALSE, csv_path = ".", tibble_name) {
   if (save_csv) {
-    path <- get_dataset_full_path(deparse(substitute(data)), csv_path)
+    path <- get_dataset_full_path(tibble_name, csv_path)
     readr::write_csv(data, path)
   }
 }
@@ -21,8 +20,13 @@ drug_sub_df <-
   function(rec,
            main_node,
            seconadary_node = NULL,
-           id = "drugbank-id") {
+           id = "drugbank-id",
+           # remove assinging to NULL after it being applied everywhere
+           progress = NULL ) {
     if (is.null(rec[[main_node]])) {
+      if (!is.null(progress)) {
+        progress$tick()
+      }
       return()
     }
     parent_key <- NULL
@@ -33,18 +37,24 @@ drug_sub_df <-
     if (is.null(seconadary_node) &&
       !is.null(rec[[main_node]])) {
       df <- xmlToDataFrame(rec[[main_node]], stringsAsFactors = FALSE)
-    } else {
+    } else if (!is.null(rec[[main_node]][[seconadary_node]])) {
       df <-
         xmlToDataFrame(rec[[main_node]][[seconadary_node]],
           stringsAsFactors = FALSE
         )
+    } else {
+      if (!is.null(progress)) {
+        progress$tick()
+      }
+      return()
     }
 
-
-
     if (nrow(df) > 0 && !is.null(parent_key)) {
       df$parent_key <- parent_key
     }
+    if (!is.null(progress)) {
+      progress$tick()
+    }
     return(df)
   }
 
@@ -95,10 +105,8 @@ read_drugbank_xml_db <- function(drugbank_db_path) {
   }
 
   if (file.exists(drugbank_db_path)) {
-    # XML_Old
     drugbank_db <- xmlParse(drugbank_db_path)
     pkg_env$root <- xmlRoot(drugbank_db)
-    pkg_env$children <- xmlChildren(pkg_env$root)
     pkg_env$version <- xmlGetAttr(pkg_env$root, name = "version")
     pkg_env$exported_date <- xmlGetAttr(pkg_env$root, name = "exported-on")
     return(TRUE)
@@ -115,13 +123,3 @@ read_drugbank_xml_db <- function(drugbank_db_path) {
     return(FALSE)
   }
 }
-
-check_parameters_validation <- function(save_table, database_connection) {
-  if (save_table && is.null(database_connection)) {
-    stop("Please provide a valid database connection.")
-  }
-
-  if (is.null(pkg_env$children)) {
-    stop("Please make sure to call read_drugbank_xml_db method first")
-  }
-}
